25. dmc_nonparametric.py — CpGtools documentation

# 25. dmc_nonparametric.py

## 25.1. Description

This program performs differential CpG analysis using the Mann-Whitney U test for two group comparison, and the Kruskal-Wallis H-test for multiple groups comparison.

## 25.2. Options

> `--version`

>   show program’s version number and exit

> `-h, --help`

>   show this help message and exit

> `-i INPUT_FILE, --input_file=INPUT_FILE`

>   Data file containing beta values with the 1st row containing sample IDs (must be unique) and the 1st column containing CpG positions or probe IDs (must be unique). Except for the 1st row and 1st column, any non-numerical values will be considered as “missing values” and ignored. This file can be a regular text file or compressed file (.gz, .bz2).

> `-g GROUP_FILE, --group=GROUP_FILE`

>   Group file defining the biological group of each sample. It is a comma-separated two columns file with the 1st column containing sample IDs, and the 2nd column containing group IDs. It must have a header row. Sample IDs should match to the “Data file”. Note: automatically switch to use Kruskal-Wallis H-test if more than two groups were defined in this file.

> `-o OUT_FILE, --output=OUT_FILE`

>   The prefix of the output file.

## 25.3. Input files (examples)

- test_05_TwoGroup.tsv.gz

- test_05_TwoGroup.grp.csv

- test_06_ThreeGroup.tsv.gz

- test_06_ThreeGroup.grp.csv

## 25.4. Command

    $dmc_nonparametric.py -i test_05_TwoGroup.tsv.gz -g test_05_TwoGroup.grp.csv -o U_test

    $dmc_nonparametric.py -i test_06_TwoGroup.tsv.gz -g test_06_TwoGroup.grp.csv -o H_test